# annorepo-client

[![GitHub Actions](https://github.com/knaw-huc/annorepo-python-client/workflows/tests/badge.svg)](https://github.com/knaw-huc/annorepo-python-client/actions)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Documentation Status](https://readthedocs.org/projects/annorepo-python-client/badge/?version=latest)](https://annorepo-python-client.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/annorepo-client)](https://pypi.org/project/annorepo-client/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/annorepo-client)](https://pypi.org/project/annorepo-client/)

A Python client for accessing an [annorepo](https://github.com/knaw-huc/annorepo) server

## installing

### using poetry

```commandline
poetry add annorepo-client
```

### using pip

```commandline
pip install annorepo-client
```

----

[USAGE](https://annorepo-python-client.readthedocs.io/en/latest/) |
[CONTRIBUTING](CONTRIBUTING.md) |
[LICENSE](LICENSE) |
[AUTHORS](AUTHORS) |
[MAINTAINERS](MAINTAINERS) |
[CONTRIBUTORS](CONTRIBUTORS)